@@ -19,18 +19,15 @@
  * USA
  */
 
-/* Lots of useful information in
- *   http://www.aafassociation.org/html/specs/aafcontainerspec-v1.0.1.pdf
+/*
+ * [MS-CFB]: Compound File Binary File Format
+ * http://msdn.microsoft.com/en-us/library/dd942138.aspx
  */
 
 #include <gsf-config.h>
-#include <gsf/gsf-infile-impl.h>
 #include <gsf/gsf-infile-msole.h>
-#include <gsf/gsf-impl-utils.h>
-#include <gsf/gsf-utils.h>
+#include <gsf/gsf.h>
 #include <gsf/gsf-msole-impl.h>
-#include <gsf/gsf-msole-utils.h>
-#include <gsf/gsf-input-proxy.h>
 
 #include <string.h>
 #include <stdio.h>
@@ -103,6 +100,21 @@ static GsfInput *gsf_infile_msole_new_child (GsfInfileMSOle *parent,
 					     MSOleDirent *dirent, GError **err);
 static void ole_info_unref (MSOleInfo *info);
 
+static gboolean
+ole_seek_block (GsfInfileMSOle const *ole, guint32 block, gsf_off_t offset)
+{
+	g_return_val_if_fail (block < ole->info->max_block, FALSE);
+
+	/* OLE_HEADER_SIZE is fixed at 512, but the sector containing the
+	 * header is padded out to bb.size (sector size) when bb.size > 512. */
+	if (gsf_input_seek (ole->input,
+		(gsf_off_t)(MAX (OLE_HEADER_SIZE, ole->info->bb.size) + (block << ole->info->bb.shift)) + offset,
+		G_SEEK_SET) < 0)
+		return FALSE;
+
+	return TRUE;
+}
+
 /**
  * ole_get_block :
  * @ole: the infile
@@ -118,13 +130,7 @@ static void ole_info_unref (MSOleInfo *info);
 static guint8 const *
 ole_get_block (GsfInfileMSOle const *ole, guint32 block, guint8 *buffer)
 {
-	g_return_val_if_fail (block < ole->info->max_block, NULL);
-
-	/* OLE_HEADER_SIZE is fixed at 512, but the sector containing the
-	 * header is padded out to bb.size (sector size) when bb.size > 512. */
-	if (gsf_input_seek (ole->input,
-		(gsf_off_t)(MAX (OLE_HEADER_SIZE, ole->info->bb.size) + (block << ole->info->bb.shift)),
-		G_SEEK_SET) < 0)
+	if (!ole_seek_block (ole, block, 0))
 		return NULL;
 
 	return gsf_input_read (ole->input, ole->info->bb.size, buffer);
@@ -442,8 +448,6 @@ ole_dup (GsfInfileMSOle const *src, GError **err)
 	}
 
 	dst = (GsfInfileMSOle *)g_object_new (GSF_INFILE_MSOLE_TYPE, NULL);
-	if (G_UNLIKELY (NULL == dst)) return NULL;
-
 	dst->input = input;
 	dst->info  = ole_info_ref (src->info);
 	/* buf and buf_size are initialized to NULL */
@@ -510,7 +514,7 @@ ole_init_info (GsfInfileMSOle *ole, GError **err)
 	info->threshold	     = GSF_LE_GET_GUINT32 (header + OLE_HEADER_THRESHOLD);
         info->sbat_start     = GSF_LE_GET_GUINT32 (header + OLE_HEADER_SBAT_START);
         info->num_sbat       = GSF_LE_GET_GUINT32 (header + OLE_HEADER_NUM_SBAT);
-	info->max_block	     = (gsf_input_size (ole->input) - OLE_HEADER_SIZE) / info->bb.size;
+	info->max_block	     = (gsf_input_size (ole->input) - OLE_HEADER_SIZE + info->bb.size -1) / info->bb.size;
 	info->sb_file	     = NULL;
 
 	if (info->num_sbat == 0 &&
@@ -640,20 +644,9 @@ static GsfInput *
 gsf_infile_msole_dup (GsfInput *src_input, GError **err)
 {
 	GsfInfileMSOle const *src = GSF_INFILE_MSOLE (src_input);
-	GsfInfileMSOle *dst = ole_dup (src, err);
+	GsfInfileMSOle *parent = GSF_INFILE_MSOLE (gsf_input_container (src_input));
 
-	if (dst == NULL)
-		return NULL;
-
-	if (src->bat.block != NULL) {
-		dst->bat.block = g_new (guint32, src->bat.num_blocks),
-		memcpy (dst->bat.block, src->bat.block,
-			sizeof (guint32) * src->bat.num_blocks);
-	}
-	dst->bat.num_blocks = src->bat.num_blocks;
-	dst->dirent = src->dirent;
-
-	return GSF_INPUT (dst);
+	return gsf_infile_msole_new_child (parent, src->dirent, err);
 }
 
 static guint8 const *
@@ -661,7 +654,6 @@ gsf_infile_msole_read (GsfInput *input, size_t num_bytes, guint8 *buffer)
 {
 	GsfInfileMSOle *ole = GSF_INFILE_MSOLE (input);
 	gsf_off_t first_block, last_block, raw_block, offset, i;
-	guint8 const *data;
 	guint8 *ptr;
 	size_t count;
 
@@ -687,9 +679,7 @@ gsf_infile_msole_read (GsfInput *input, size_t num_bytes, guint8 *buffer)
 	if (i > last_block) {
 		/* optimization don't seek if we don't need to */
 		if (ole->cur_block != first_block) {
-			if (gsf_input_seek (ole->input,
-				(gsf_off_t)(MAX (OLE_HEADER_SIZE, ole->info->bb.size) + (ole->bat.block [first_block] << ole->info->bb.shift) + offset),
-				G_SEEK_SET) < 0)
+			if (!ole_seek_block (ole, ole->bat.block [first_block], offset))
 				return NULL;
 		}
 		ole->cur_block = last_block;
@@ -711,12 +701,10 @@ gsf_infile_msole_read (GsfInput *input, size_t num_bytes, guint8 *buffer)
 		count = ole->info->bb.size - offset;
 		if (count > num_bytes)
 			count = num_bytes;
-		data = ole_get_block (ole, ole->bat.block [i], NULL);
-		if (data == NULL)
+		if (!ole_seek_block (ole, ole->bat.block [i], offset))
+			return NULL;
+		if (!gsf_input_read (ole->input, count, ptr))
 			return NULL;
-
-		/* TODO : this could be optimized to avoid the copy */
-		memcpy (ptr, data + offset, count);
 		offset = 0;
 	}
 	ole->cur_block = BAT_MAGIC_UNUSED;
@@ -801,7 +789,7 @@ gsf_infile_msole_new_child (GsfInfileMSOle *parent,
 
 		for (i = 0 ; remaining > 0 && i < child->bat.num_blocks; i++, remaining -= info->sb.size)
 			if (gsf_input_seek (GSF_INPUT (sb_file),
-				(gsf_off_t)(child->bat.block [i] << info->sb.shift), G_SEEK_SET) < 0 ||
+					    (gsf_off_t)(child->bat.block [i] << info->sb.shift), G_SEEK_SET) < 0 ||
 			    (data = gsf_input_read (GSF_INPUT (sb_file),
 						    MIN (remaining, (int)info->sb.size),
 						    child->stream.buf + (i << info->sb.shift))) == NULL) {
@@ -829,10 +817,12 @@ gsf_infile_msole_child_by_index (GsfInfile *infile, int target, GError **err)
 	GsfInfileMSOle *ole = GSF_INFILE_MSOLE (infile);
 	GList *p;
 
-	for (p = ole->dirent->children; p != NULL ; p = p->next)
+	for (p = ole->dirent->children; p != NULL ; p = p->next) {
+		MSOleDirent *dirent = p->data;
 		if (target-- <= 0)
-			return gsf_infile_msole_new_child (ole,
-				(MSOleDirent *)p->data, err);
+			return gsf_infile_msole_new_child
+				(ole, dirent, err);
+	}
 	return NULL;
 }
 
@@ -842,9 +832,11 @@ gsf_infile_msole_name_by_index (GsfInfile *infile, int target)
 	GsfInfileMSOle *ole = GSF_INFILE_MSOLE (infile);
 	GList *p;
 
-	for (p = ole->dirent->children; p != NULL ; p = p->next)
+	for (p = ole->dirent->children; p != NULL ; p = p->next) {
+		MSOleDirent *dirent = p->data;
 		if (target-- <= 0)
-			return ((MSOleDirent *)p->data)->name;
+			return dirent->name;
+	}
 	return NULL;
 }
 
@@ -929,8 +921,6 @@ gsf_infile_msole_new (GsfInput *source, GError **err)
 	g_return_val_if_fail (GSF_IS_INPUT (source), NULL);
 
 	ole = (GsfInfileMSOle *)g_object_new (GSF_INFILE_MSOLE_TYPE, NULL);
-	if (G_UNLIKELY (NULL == ole)) return NULL;
-
 	ole->input = gsf_input_proxy_new (source);
 	gsf_input_set_size (GSF_INPUT (ole), 0);
 
