@@ -21,12 +21,9 @@
  */
 
 #include <gsf-config.h>
-#include <gsf/gsf-infile-impl.h>
 #include <gsf/gsf-infile-zip.h>
-#include <gsf/gsf-impl-utils.h>
-#include <gsf/gsf-utils.h>
+#include <gsf/gsf.h>
 #include <gsf/gsf-zip-impl.h>
-#include <gsf/gsf-input-proxy.h>
 
 #include <string.h>
 #include <zlib.h>
@@ -274,7 +271,6 @@ zip_dup (GsfInfileZip const *src, GError **err)
 	dst = g_object_new (GSF_INFILE_ZIP_TYPE,
 			    "internal-parent", src,
 			    NULL);
-	if (G_UNLIKELY (NULL == dst)) return NULL;
 
 	if (dst->err) {
 		if (err)
@@ -419,6 +415,9 @@ zip_child_init (GsfInfileZip *child, GError **errmsg)
 		return TRUE;
 	}
 
+	/* Throw clang a bone.  */
+	g_assert (data != NULL);
+
 	name_len =   GSF_LE_GET_GUINT16 (data + ZIP_FILE_HEADER_NAME_SIZE);
 	extras_len = GSF_LE_GET_GUINT16 (data + ZIP_FILE_HEADER_EXTRAS_SIZE);
 
@@ -876,7 +875,6 @@ gsf_infile_zip_new (GsfInput *source, GError **err)
 	zip = g_object_new (GSF_INFILE_ZIP_TYPE,
 			    "source", source,
 			    NULL);
-	if (G_UNLIKELY (NULL == zip)) return NULL;
 
 	if (zip->err) {
 		if (err)
