@@ -21,14 +21,11 @@
 
 #include <gsf-config.h>
 #include <gsf-input-bzip.h>
-#include <gsf-input-memory.h>
-#include <gsf-output-memory.h>
-#include <gsf-input-impl.h>
+#include <gsf.h>
+
 #include <string.h>
 
 #ifdef HAVE_BZ2
-/* For getting FILE.  Don't ask.  */
-#include <stdio.h>
 #include <bzlib.h>
 #define BZ_BUFSIZ 1024
 #endif
