@@ -21,10 +21,8 @@
 
 #include <gsf-config.h>
 #include <gsf/gsf-input-gio.h>
-#include <gsf/gsf-input-memory.h>
-#include <gsf/gsf-output-memory.h>
-#include <gsf/gsf-input-impl.h>
-#include <gsf/gsf-impl-utils.h>
+#include <gsf/gsf.h>
+
 #include <string.h>
 
 struct _GsfInputGio {
@@ -148,11 +146,6 @@ gsf_input_gio_new (GFile *file, GError **err)
 	}
 
 	input = g_object_new (GSF_INPUT_GIO_TYPE, NULL);
-	if (G_UNLIKELY (NULL == input)) {
-		g_input_stream_close (stream, NULL, NULL);
-		g_object_unref (stream);
-		return NULL;
-	}
 
 	gsf_input_set_size (GSF_INPUT (input), filesize);
 
