@@ -22,12 +22,9 @@
 
 #include <gsf-config.h>
 #include <gsf/gsf-input-gzip.h>
-#include <gsf/gsf-input-impl.h>
-#include <gsf/gsf-impl-utils.h>
-#include <gsf/gsf-utils.h>
+#include <gsf/gsf.h>
 
 #include <zlib.h>
-#include <stdio.h>
 #include <string.h>
 
 #define Z_BUFSIZE 0x100
@@ -215,7 +212,6 @@ gsf_input_gzip_new (GsfInput *source, GError **err)
 	gzip = g_object_new (GSF_INPUT_GZIP_TYPE,
 			     "source", source,
 			     NULL);
-	if (G_UNLIKELY (NULL == gzip)) return NULL;
 
 	if (gzip->err) {
 		if (err)
@@ -267,9 +263,6 @@ gsf_input_gzip_dup (GsfInput *src_input, GError **err)
 	if (src_source_copy)
 		g_object_unref (src_source_copy);
 
-	if (G_UNLIKELY (NULL == dst))
-		return NULL;
-
 	if (src->err) {
 		g_clear_error (&dst->err);
 		dst->err = g_error_copy (src->err);
