@@ -21,8 +21,7 @@
 
 #include <gsf-config.h>
 #include <gsf/gsf-input-textline.h>
-#include <gsf/gsf-input-impl.h>
-#include <gsf/gsf-impl-utils.h>
+#include <gsf/gsf.h>
 
 #include <string.h>
 
@@ -62,8 +61,6 @@ gsf_input_textline_new (GsfInput *source)
 	g_return_val_if_fail (source != NULL, NULL);
 
 	input = g_object_new (GSF_INPUT_TEXTLINE_TYPE, NULL);
-	if (G_UNLIKELY (NULL == input)) return NULL;
-
 	input->source = g_object_ref (source);
 	input->buf = NULL;
 	input->buf_size = 0;
@@ -94,7 +91,6 @@ gsf_input_textline_dup (GsfInput *src_input, G_GNUC_UNUSED GError **err)
 {
 	GsfInputTextline const *src = (GsfInputTextline *)src_input;
 	GsfInputTextline *dst = g_object_new (GSF_INPUT_TEXTLINE_TYPE, NULL);
-	if (G_UNLIKELY (NULL == dst)) return NULL;
 
 	dst->source = g_object_ref (src->source);
 	gsf_input_set_size (GSF_INPUT (dst), gsf_input_size (src_input));
