@@ -20,14 +20,10 @@
  */
 
 #include <gsf-config.h>
-#include <gsf/gsf-input-impl.h>
-#include <gsf/gsf-input-gzip.h>
-#include <gsf/gsf-impl-utils.h>
-#include <string.h>
+#include <gsf/gsf-input.h>
+#include <gsf/gsf.h>
 
-#ifdef HAVE_BZ2
-#include <gsf/gsf-input-bzip.h>
-#endif
+#include <string.h>
 
 #define GET_CLASS(instance) G_TYPE_INSTANCE_GET_CLASS (instance, GSF_INPUT_TYPE, GsfInputClass)
 
@@ -170,7 +166,8 @@ GSF_CLASS_ABSTRACT (GsfInput, gsf_input,
  *
  * The name of the input stream.
  *
- * Returns: @input's name in utf8 form, or %NULL if it has no name.
+ * Returns: (transfer none): @input's name in utf8 form, or %NULL if it
+ * has no name.
  **/
 char const *
 gsf_input_name (GsfInput *input)
@@ -289,18 +286,19 @@ gsf_input_eof (GsfInput *input)
 }
 
 /**
- * gsf_input_read:
+ * gsf_input_read: (skip)
  * @input: the input stream
  * @num_bytes: number of bytes to read
- * @optional_buffer: %NULL, or pointer to destination memory area
+ * @optional_buffer: Pointer to destination memory area
  *
  * Read at least @num_bytes.  Does not change the current position if there
  * is an error.  Will only read if the entire amount can be read.  Invalidates
  * the buffer associated with previous calls to gsf_input_read.
  *
- * Returns: pointer to the buffer or %NULL if there is an error or 0 bytes are
- * 	requested.
+ * Returns: pointer to the buffer or %NULL if there is an error or 0
+ * bytes are requested.
  **/
+
 guint8 const *
 gsf_input_read (GsfInput *input, size_t num_bytes, guint8 *optional_buffer)
 {
@@ -309,7 +307,7 @@ gsf_input_read (GsfInput *input, size_t num_bytes, guint8 *optional_buffer)
 
 	g_return_val_if_fail (input != NULL, NULL);
 
-	if (num_bytes == 0 || newpos > input->size)
+	if (newpos <= input->cur_offset || newpos > input->size)
 		return NULL;
 	res = GET_CLASS (input)->Read (input, num_bytes, optional_buffer);
 	if (res == NULL)
@@ -319,6 +317,42 @@ gsf_input_read (GsfInput *input, size_t num_bytes, guint8 *optional_buffer)
 	return res;
 }
 
+/**
+ * gsf_input_read0:
+ * @input: the input stream
+ * @num_bytes: (in): number of bytes to read
+ * @bytes_read: (out): copy of @num_bytes
+ *
+ * Read @num_bytes.  Does not change the current position if there
+ * is an error.  Will only read if the entire amount can be read.
+ *
+ * Returns: (array length=bytes_read) (element-type guint8) (transfer full):
+ * the data read.
+ *
+ * Rename to: gsf_input_read
+ **/
+
+guint8 *
+gsf_input_read0 (GsfInput *input, size_t num_bytes, size_t *bytes_read)
+{
+	guint8 *res;
+
+	g_return_val_if_fail (input != NULL, FALSE);
+	g_return_val_if_fail (bytes_read != NULL, FALSE);
+
+	*bytes_read = num_bytes;
+
+	if (num_bytes > (size_t)gsf_input_remaining (input))
+		return NULL;
+
+	res = g_new (guint8, num_bytes);
+	if (gsf_input_read (input, num_bytes, res))
+		return res;
+
+	g_free (res);
+	return NULL;
+}
+
 /**
  * gsf_input_remaining:
  * @input: the input stream
@@ -598,7 +632,6 @@ gsf_input_uncompress (GsfInput *src)
 		}
 	}
 
-#ifdef HAVE_BZ2
 	/* Let's try bzip.  */
 	{
 		guint8 const *bzip_sig = "BZh";
@@ -611,7 +644,6 @@ gsf_input_uncompress (GsfInput *src)
 			}
 		}
 	}
-#endif
 
 	/* Other methods go here.  */
 
