@@ -21,17 +21,21 @@
 
 #include <gsf-config.h>
 #include <gsf/gsf-libxml.h>
-#include <gsf/gsf-input.h>
-#include <gsf/gsf-output.h>
-#include <gsf/gsf-input-gzip.h>
-#include <gsf/gsf-impl-utils.h>
-#include <gsf/gsf-utils.h>
-#include <gsf/gsf-timestamp.h>
+#include <gsf/gsf.h>
+
 #include <glib/gi18n-lib.h>
 
 #include <math.h>
 #include <string.h>
 
+/* Dead kittens.  */
+#ifndef HAVE_G_VALUE_SET_SCHAR
+#define g_value_set_schar(v_,sc_) g_value_set_char((v_),(char)(sc_))
+#endif
+#ifndef HAVE_G_VALUE_GET_SCHAR
+#define g_value_get_schar(v_) (signed char)g_value_get_char((v_))
+#endif
+
 static GObjectClass *parent_class;
 
 static gint
@@ -218,7 +222,7 @@ gsf_xml_gvalue_from_str (GValue *res, GType t, char const *str)
 
 	switch (t) {
 	case G_TYPE_CHAR:
-		g_value_set_char (res, str[0]);
+		g_value_set_schar (res, (signed char)(str[0]));
 		break;
 	case G_TYPE_UCHAR:
 		g_value_set_uchar (res, (guchar)str[0]);
@@ -1953,7 +1957,7 @@ gsf_xml_out_add_gvalue (GsfXMLOut *xout, char const *id, GValue const *val)
 	switch (t) {
 	case G_TYPE_CHAR: {
 		char c[2] = { 0, 0 };
-		c[0] = g_value_get_char (val);
+		c[0] = (char)g_value_get_schar (val);
 		/* FIXME: What if we are in 0x80-0xff? */
 		gsf_xml_out_add_cstr (xout, id, c);
 		break;
