@@ -22,23 +22,20 @@
  */
 
 #include <gsf-config.h>
-#include <gsf/gsf-docprop-vector.h>
 #include <gsf/gsf-msole-utils.h>
-#include <gsf/gsf-input.h>
-#include <gsf/gsf-output.h>
-#include <gsf/gsf-utils.h>
-#include <gsf/gsf-timestamp.h>
-#include <gsf/gsf-meta-names.h>
-#include <gsf/gsf-doc-meta-data.h>
-#include <gsf/gsf-clip-data.h>
+#include <gsf/gsf.h>
 
 #include <locale.h>
 #include <stdlib.h>
 #include <string.h>
-#include <stdio.h>
 #include <time.h>
 #include <glib/gi18n-lib.h>
 
+/* Dead kittens.  */
+#ifndef HAVE_G_VALUE_SET_SCHAR
+#define g_value_set_schar(v_,sc_) g_value_set_char((v_),(char)(sc_))
+#endif
+
 #define NO_DEBUG_OLE_PROPS
 #ifndef NO_DEBUG_OLE_PROPS
 #define d(code)	do { code } while (0)
@@ -682,10 +679,10 @@ msole_prop_parse (GsfMSOleMetaDataSection *section,
 		break;
 
 	case VT_I1 :
-		/* 1-byte unsigned integer */
+		/* 1-byte signed integer */
 		NEED_BYTES (1);
 		g_value_init (res, G_TYPE_CHAR);
-		g_value_set_char (res, GSF_LE_GET_GINT8 (*data));
+		g_value_set_schar (res, GSF_LE_GET_GINT8 (*data));
 		ADVANCE;
 		break;
 
@@ -1621,6 +1618,17 @@ msole_metadata_write_section (WritePropState *state, gboolean user)
 		}
 	}
 
+	while (i < count) {
+		static gboolean warned = FALSE;
+		if (!warned) {
+			warned = TRUE;
+			g_warning ("Something strange in msole_metadata_write_section");
+		}
+		offsets[i].id = 0;
+		offsets[i].offset = offsets[i - 1].offset;
+		i++;
+	}
+
 	len = gsf_output_tell (state->out) - base;
 	gsf_output_seek (state->out, base, G_SEEK_SET);
 	GSF_LE_SET_GUINT32 (buf, len);
