@@ -25,12 +25,10 @@
 
 #include <gsf-config.h>
 #include <gsf/gsf-opendoc-utils.h>
-#include <gsf/gsf-meta-names.h>
-#include <gsf/gsf-doc-meta-data.h>
-#include <gsf/gsf-timestamp.h>
-#include <gsf/gsf-docprop-vector.h>
-#include <gsf/gsf-impl-utils.h>
+#include <gsf/gsf.h>
+
 #include <string.h>
+
 #include <glib/gi18n-lib.h>
 
 
@@ -46,6 +44,7 @@ typedef struct {
 
 /**
  * gsf_odf_get_version_string:
+ *
  * Gives the ODF version used by libgsf when writing Open Document files.
  *
  * Since: 1.14.24
@@ -60,6 +59,7 @@ gsf_odf_get_version_string (void)
 
 /**
  * get_gsf_odf_version_string: (skip)
+ *
  * Gives the ODF version used by libgsf when writing Open Document files.
  *
  * Deprecated: 1.14.24, use gsf_odf_get_version_string
@@ -74,6 +74,7 @@ get_gsf_odf_version_string (void)
 
 /**
  * gsf_odf_get_version:
+ *
  * Gives the ODF version used by libgsf when writing Open Document files.
  *
  * Since: 1.14.24
@@ -88,6 +89,7 @@ gsf_odf_get_version (void)
 
 /**
  * get_gsf_odf_version: (skip)
+ *
  * Gives the ODF version used by libgsf when writing Open Document files.
  *
  * Deprecated: 1.14.24, use gsf_odf_get_version
