@@ -20,12 +20,9 @@
  */
 
 #include <gsf-config.h>
-#include <gsf/gsf-outfile-impl.h>
 #include <gsf/gsf-outfile-stdio.h>
-#include <gsf/gsf-output-impl.h>
-#include <gsf/gsf-output-stdio.h>
-#include <gsf/gsf-impl-utils.h>
-#include <gsf/gsf-utils.h>
+#include <gsf/gsf.h>
+
 #include <glib/gstdio.h>
 
 #include <errno.h>
