@@ -20,10 +20,8 @@
  */
 
 #include <gsf-config.h>
-#include <gsf/gsf-outfile-impl.h>
 #include <gsf/gsf-outfile-zip.h>
-#include <gsf/gsf-impl-utils.h>
-#include <gsf/gsf-utils.h>
+#include <gsf/gsf.h>
 #include <gsf/gsf-zip-impl.h>
 
 #include <string.h>
