@@ -21,12 +21,9 @@
 
 #include <gsf-config.h>
 #include <gsf/gsf-output-gzip.h>
-#include <gsf/gsf-output-impl.h>
-#include <gsf/gsf-impl-utils.h>
-#include <gsf/gsf-utils.h>
+#include <gsf/gsf.h>
 
 #include <zlib.h>
-#include <stdio.h>
 #include <time.h>
 #include <string.h>
 
@@ -123,7 +120,6 @@ gsf_output_gzip_new (GsfOutput *sink, GError **err)
 	g_return_val_if_fail (GSF_IS_OUTPUT (sink), NULL);
 
 	output = g_object_new (GSF_OUTPUT_GZIP_TYPE, "sink", sink, NULL);
-	if (G_UNLIKELY (NULL == output)) return NULL;
 
 	con_err = gsf_output_error (output);
 
