@@ -20,8 +20,7 @@
  */
 #include <gsf-config.h>
 #include <gsf/gsf-output-iochannel.h>
-#include <gsf/gsf-output-impl.h>
-#include <gsf/gsf-impl-utils.h>
+#include <gsf/gsf.h>
 
 static GsfOutputClass *parent_class;
 
@@ -48,7 +47,6 @@ gsf_output_iochannel_new (GIOChannel *channel)
 	g_return_val_if_fail (channel != NULL, NULL);
 
 	output = g_object_new (GSF_OUTPUT_IOCHANNEL_TYPE, NULL);
-	if (G_UNLIKELY (NULL == output)) return NULL;
 
 	output->channel = channel;
 	return GSF_OUTPUT (output);
