@@ -20,8 +20,8 @@
  */
 #include <gsf-config.h>
 #include <gsf/gsf-output-memory.h>
-#include <gsf/gsf-output-impl.h>
-#include <gsf/gsf-impl-utils.h>
+#include <gsf/gsf.h>
+
 #include <string.h>
 
 #define MIN_BLOCK 512
