@@ -21,51 +21,12 @@
 
 #include <gsf-config.h>
 #include <gsf/gsf-utils.h>
-#include <gsf/gsf-input.h>
-#include <gsf/gsf-doc-meta-data.h>
-#include <gsf/gsf-docprop-vector.h>
-#include <gsf/gsf-impl-utils.h>
-
-#include <gsf/gsf-infile.h>
-#include <gsf/gsf-infile-msole.h>
-#include <gsf/gsf-infile-msvba.h>
-#include <gsf/gsf-infile-stdio.h>
-#include <gsf/gsf-infile-zip.h>
-
-#include <gsf/gsf-input.h>
-#include <gsf/gsf-input-gzip.h>
-#include <gsf/gsf-input-http.h>
-#include <gsf/gsf-input-memory.h>
-#include <gsf/gsf-input-proxy.h>
-#include <gsf/gsf-input-stdio.h>
-#include <gsf/gsf-input-textline.h>
-
-#include <gsf/gsf-output.h>
-#include <gsf/gsf-output-bzip.h>
-#include <gsf/gsf-output-csv.h>
-#include <gsf/gsf-output-gzip.h>
-#include <gsf/gsf-output-iconv.h>
-#include <gsf/gsf-output-iochannel.h>
-#include <gsf/gsf-output-memory.h>
-#include <gsf/gsf-output-stdio.h>
-
-#include <gsf/gsf-outfile.h>
-#include <gsf/gsf-outfile-msole.h>
-#include <gsf/gsf-outfile-stdio.h>
-#include <gsf/gsf-outfile-zip.h>
-
-#include <gsf/gsf-libxml.h>
-#include <gsf/gsf-blob.h>
-#include <gsf/gsf-structured-blob.h>
-#include <gsf/gsf-shared-memory.h>
-#include <gsf/gsf-clip-data.h>
-#include <gsf/gsf-open-pkg-utils.h>
+#include <gsf/gsf.h>
 
 #include <gobject/gvaluecollector.h>
 #include <glib/gi18n-lib.h>
 
 #include <ctype.h>
-#include <stdio.h>
 #include <string.h>
 
 /*
@@ -220,8 +181,10 @@ gsf_init_dynamic (GTypeModule *module)
 	}
 #endif
 	REGISTER (gsf_input);
+	/* REGISTER (gsf_input_bzip); */
 	REGISTER (gsf_input_gzip);
 	REGISTER (gsf_input_http);
+	/* REGISTER (gsf_input_iochannel); */
 	REGISTER (gsf_input_memory);
 	REGISTER (gsf_input_proxy);
 	REGISTER (gsf_input_stdio);
@@ -231,6 +194,7 @@ gsf_init_dynamic (GTypeModule *module)
 	REGISTER (gsf_infile_msole);
 	REGISTER (gsf_infile_msvba);
 	REGISTER (gsf_infile_stdio);
+	REGISTER (gsf_infile_tar);
 	REGISTER (gsf_infile_zip);
 
 	REGISTER (gsf_output);
@@ -265,7 +229,7 @@ gsf_init_dynamic (GTypeModule *module)
 }
 
 /**
- * gsf_shutdown:
+ * gsf_shutdown_dynamic:
  *
  * De-intializes the GSF library from a type module.
  * Currently does nothing.
@@ -353,7 +317,7 @@ gsf_input_dump (GsfInput *input, gboolean dump_as_hex)
 }
 
 /**
- * gsf_le_get_guint64
+ * gsf_le_get_guint64:
  * @p: pointer to storage
  *
  * Interpret binary data as a guint64 (8 byte unsigned integer type) in little
