@@ -1,23 +1,11 @@
 /* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 
-#include <gsf/gsf-infile-msole.h>
-#include <gsf/gsf-infile-tar.h>
-#include <gsf/gsf-infile-zip.h>
-#include <gsf/gsf-infile.h>
-#include <gsf/gsf-input-stdio.h>
-#include <gsf/gsf-output-stdio.h>
-#include <gsf/gsf-outfile.h>
-#include <gsf/gsf-outfile-msole.h>
-#include <gsf/gsf-outfile-zip.h>
-#include <gsf/gsf-utils.h>
-#include <gsf/gsf-doc-meta-data.h>
-#include <gsf/gsf-msole-utils.h>
+#include <gsf-config.h>
+#include <gsf/gsf.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <string.h>
 
-#define GETTEXT_PACKAGE NULL /* FIXME */
-
 static gboolean show_version;
 
 static GOptionEntry const gsf_options [] = {
@@ -247,7 +235,7 @@ get_meta_data (GsfInfile *infile, const char *filename)
 
 		in = gsf_infile_child_by_name (infile, "\05SummaryInformation");
 		if (NULL != in) {
-			err = gsf_msole_metadata_read (in, meta_data);
+			err = gsf_doc_meta_data_read_from_msole (meta_data, in);
 			if (err != NULL) {
 				g_warning ("'%s' error: %s", filename, err->message);
 				g_error_free (err);
@@ -258,7 +246,7 @@ get_meta_data (GsfInfile *infile, const char *filename)
 
 		in = gsf_infile_child_by_name (infile, "\05DocumentSummaryInformation");
 		if (NULL != in) {
-			err = gsf_msole_metadata_read (in, meta_data);
+			err = gsf_doc_meta_data_read_from_msole (meta_data, in);
 			if (err != NULL) {
 				g_warning ("'%s' error: %s", filename, err->message);
 				g_error_free (err);
